@@ -30,5 +30,6 @@
                           "The latest version is: ", remote_version, "\n\n",
                           "To access the latest version, please run \n",
                           "devtools::install_github('edsandorf/obfuscatoR') \n\n",
-                          "To cite this package: Sandorf, E. D., Chorus, C. & van Cranenburgh, S., 2019, obfuscatoR: An R Package for the Obfuscation Game, https://CRAN.R-project.org/package=obfuscatoR \n")
+                          "To cite this package: \n",
+        "utils::citation('obfuscatoR')")
 }
